Documentation: http://doxx.org

What is doxx?
----------------

doxx is a generic text file project build and distribution system. It supports simple YAML formatted build specs and build time text file customization using local or remote text templates (that can be hosted anywhere).

For those who prefer the ready-made approach, the [doxx Package Repository](https://github.com/doxx-repo) contains a growing list of resusable, common project types that can be built with a simple set of doxx commands.

Features include:

- Simple, legible YAML syntax build specs that do not require scripting/programming know-how
- Local template file support
- Remote template file support (from any hosting site that supports GET requests)
- Full UTF-8 character set support in templates, named text replacement tags in templates, and replacement strings entered by users
- Generic text project support.  Use it for anything from a Bootstrap framework driven website to a statistical analysis script stub.  If it contains text, it should work.
- Support for the distribution of binary files with your projects
- Multi-processor template file build support

Additional information is available in `the documentation <http://doxx.org>`_.


Quickstart Guides
-----------------------

User Quickstart Guide
^^^^^^^^^^^^^^^^^^^^^^^^^^^

The `User Quickstart Guide <http://doxx.org/quickstart/user/>`_ is for anyone who would like to learn how to build projects from third party developers or from the doxx Package Repository.


Developer Quickstart Guide
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

The `Developer Quickstart Guide <http://doxx.org/quickstart/dev/>`_ is for anyone who would like to learn how to develop and distribute reusable, templated projects with doxx.


Usage
----------

The `Usage Documentation <http://doxx.org/usage/syntax/>`_ lists the complete set of available commands and options.



Changes
-----------

Changes are found on `the Changelog <http://doxx.org/more/changelog/>`_.



Issues
----------------

Please `submit a new issue report <https://github.com/chrissimpkins/doxx/issues/new>`_ on the Github repository.


License
-----------

The doxx command line application is licensed under the `MIT License <https://github.com/chrissimpkins/doxx/blob/master/docs/LICENSE>`_.

Project packages distributed through the doxx Package Repository are licensed under a variety of open source licenses.  Please review the respective project documentation for additional information.


Source
-----------

Source code is available on the `Github repository <https://github.com/chrissimpkins/doxx>`_.

